@@ -1,8 +1,9 @@
 '''
 avispa_lattices
 avispa_lattices.utils
-avispa_lattices.base_methods
-avispa_lattices.base_generation
 avispa_lattices.testing
+avispa_lattices.random
 avispa_lattices.package_info
+avispa_lattices.lattice
+avispa_lattices.visualization
 '''
\ No newline at end of file
